library("testthat")
library("arulesCBA")

testthat::test_check("arulesCBA")
